<!--安全排查-->
<template>
  <div class="mobile-device">
    <!--  头部  -->
    <van-sticky>
      <van-nav-bar
        title="安全排查"
        left-arrow
        @click-left="_ => $router.go(-1)"
        @click-right="showPopup('querySearchPopup')"
      >
        <template #right>
          <van-icon name="search" size="18" />
        </template>
      </van-nav-bar>
    </van-sticky>

    <div class="mobile-refresh">
      <van-pull-refresh
        v-model="refreshing"
        @refresh="onRefresh"
        class="van-hairline--top"
      >
        <van-list
          v-model="loading"
          :finished="finished"
          :immediate-check="false"
          finished-text="没有更多了"
          @load="onLoad"
        >
          <div
            v-for="(item, index) in listData"
            :key="index"
            class="device van-hairline--bottom"
            :class="{myStyle: index === listData.length - 1}"
            @click="handleDetail(item)"
          >
            <div class="device-item">
              <div class="device-item-text">
                <div class="device-item-content" style="margin-bottom: 6px">
                  <div>
                    <div class="device-name">
                      {{ item.recordName }}
                    </div>
                  </div>
                </div>
              </div>
              <div class="device-content">
                <p>
                  <span style="color:#333">受检单位：</span
                  >{{ item.unitName }}
                </p>
                <p style="display:flex">
                  <span style="color:#333">整改状态：</span>
                  <van-tag :type="dictionaryEscape(statusOpt, item.status, {labelKey: 'type'}) ">
                    {{ dictionaryEscape(statusOpt, item.status) }}
                  </van-tag>
                </p>
                <p>
                  <span style="color:#333">排查方案：</span>
                  {{ dictionaryEscape(troubleshootingPlanOpt, item.checkschemeId) }}
                </p>
                <p style="display:flex">
                  <span style="color:#333">受检单位类型：</span>
                  {{ dictionaryEscape(unitsTypeOpt, item.unitType) }}
                </p>
                <p>
                  <span style="color:#333">最后排查时间：</span
                  >{{ item.checkDate }}
                </p>
                <p>
                  <span style="color:#333">负责人：</span
                  >{{ item.unitUsername }}
                </p>
                <p>
                  <span style="color:#333">联系电话：</span
                  >{{ item.unitUserphone }}
                </p>
              </div>
            </div>
          </div>
        </van-list>
      </van-pull-refresh>
    </div>

    <!-- 列表筛选弹层 -->
    <QuerySearchPopup
      :querySearchPopup.sync="querySearchPopup"
      :customQueryPrams="customQueryPrams"
      :troubleshootingPlanOpt="troubleshootingPlanOpt"
      :unitsTypeOpt="unitsTypeOpt"
      :statusOpt="statusOpt"
      @searchData="searchData"
    />

  </div>
</template>

<script>
import programApi from '@/views/Manage/saftyDanger/api/programApi'
import DingMaterialApi from '../api/DingMaterialApi'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import QuerySearchPopup from './components/QuerySearchPopup/index.vue'

const {loadCmgtSaftyDangerUnit} = programApi
const {loadCmgtSaftyDangerCheckrecord} = DingMaterialApi

export default {
  name: 'MobileSaftyDangerCheckPlan',
  components: {QuerySearchPopup},
  // 安全排查
  data() {
    return {
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'checkschemeId', // 排查方案
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'status', // 整改状态
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'unit_type_', // 受检单位类型
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'unit_name_', // 受检单位
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'checkDate', // 最后复查时间
          relation: 'AND',
          value: ''
        }
      ],
      // 自定义请求参数配置对象
      customQueryPrams: {
        pageSize: 10,
        page: 1,
        checkschemeId: '',
        status: '',
        unit_type_: '',
        unit_name_: '',
        checkDate: ''
      },
      listData: [], // 列表数据
      troubleshootingPlanOpt: [], // 排查方案配置数组对象
      // 受检单位配置数组对象
      unitsTypeOpt: [
        {text: '所有受检单位', value: ''},
        ...dictUtils.getDictItemsFromCache('zhgl-dwlx').map(i => {
          return {text: i.name, value: i.value}
        })
      ],
      // 整改状态配置数组对象
      statusOpt: [
        {text: '所有', value: '', type: 'primary'},
        {text: '待排查', value: '1', type: 'danger'},
        {text: '整改中', value: '2', type: 'warning'},
        {text: '已完成', value: '3', type: 'success'}
      ],
      querySearchPopup: false, // 搜索弹层
      loading: false, // 列表加载loading状态
      finished: false, // 是否数据加载完毕
      refreshing: false // 下拉刷新
    }
  },
  computed: {
    // 加工为后端需要的请求格式
    queryParams() {
      const {pageSize, page, ...item} = this.customQueryPrams
      return {
        pageBean: {pageSize, page},
        querys: this.querys.map(i => {
          return {...i, value: item[i.property]}
        })
      }
    }
  },
  created() {
    this.getTroubleshootingPlanOpt() // 获取排查方案配置数组对象
    this.getListData() // 获取列表数据
  },
  methods: {
    // 字典转义(转义、翻译)
    dictionaryEscape(dictionary, val, option = {}) {
      if (!(Array.isArray(dictionary) && dictionary.length)) return ''
      option = {
        valueKey: 'value',
        labelKey: 'text',
        dictionaryType: true,// true 为转义 false 为翻译
        ...option
      }
      const {valueKey, labelKey, dictionaryType} = option
      let item = dictionary.find(i => i[dictionaryType ? valueKey : labelKey] === val) || {}
      return item[dictionaryType ? labelKey : valueKey] || ''
    },

    // 获取排查方案配置数组对象
    getTroubleshootingPlanOpt() {
      loadCmgtSaftyDangerUnit(
        {
          pageBean: {
            pageSize: -1, page: 1
          },
          querys: [
            {
              group: 'main',
              operation: 'EQUAL',
              parentGroup: '',
              property: 'pubState',
              relation: 'AND',
              value: 2
            }
          ]
        },
        res => {
          this.troubleshootingPlanOpt = [
            {text: '所有排查方案', value: ''},
            ...res.rows.map(item => {
              return {text: item.schemeName, value: item.pkVal}
            })
          ]
        }
      )
    },

    // 跳转设备详情
    handleDetail(item) {
      this.$router.push({
        name: 'MobileSaftyDangerCheckPlanDetail',
        query: {id: item.id}
      })
    },

    // 触底时触发
    onLoad() {
      this.customQueryPrams.page++
      this.getListData(_ => this.loading = false)
    },

    // 下拉时触发
    onRefresh() {
      this.customQueryPrams.page = 1
      this.listData = []
      this.getListData(_ => this.refreshing = false)
    },

    // 获取列表数据
    async getListData(callback) {
      /*
      * 定义 escapeOpt 字段对应字典名 对象，后续进行字段的翻译逻辑
      * queryParams 为重新加工结构赋值的新请求配置参数
      * */
      const escapeOpt = {
        status: 'statusOpt',
        unit_type_: 'unitsTypeOpt',
        checkschemeId: 'troubleshootingPlanOpt'
      }
      const queryParams = {
        ...this.queryParams,
        querys: this.queryParams.querys.map(i => {
          if (i.property === 'checkDate') {
            return {
              ...i,
              value: i.value === '' ? '' : i.value.split(' ~ ')
            }
          }
          let escape = this[escapeOpt[i.property]]
          if (!escape) return i
          return {
            ...i,
            value: this.dictionaryEscape(escape, i.value, {dictionaryType: false})
          }
        })
      }

      const {data: {rows, total}} = await loadCmgtSaftyDangerCheckrecord(queryParams)
      const {pageSize, page} = this.customQueryPrams
      this.listData = this.listData.concat(rows)
      this.$nextTick(_ => callback && callback())
      if (pageSize * page >= total) this.finished = true
    },

    // 打开弹层
    showPopup(popupName) {
      this[popupName] = true
    },


    // 查询/重置按钮点击
    searchData() {
      this.finished = false
      this.customQueryPrams.page = 1
      this.listData = []
      this.getListData()
    }
  }
}
</script>

<style lang="scss" scoped>
@import '@/assets/css/element-variables';

.van-cell__title span,
.van-cell__value span {
  font-size: 82px;
}

.van-cell__value span {
  color: $--mobile-text-active;
}

::v-deep .device .device-item-text[data-v-677e860a] {
  border-bottom: 0;
}

.search-box {
  width: 100%;
  z-index: 10;
  // padding-top: 200px;
}

.popup-content {
  height: 86%;
  overflow-y: scroll;
}

.confirm-button {
  width: 90%;
  position: fixed;
  bottom: 20px;
  display: flex;
  justify-content: space-evenly;
}

.mobile-device {
  height: 100%;
  background-color: #f9f9f9;
}

.mobile-refresh {
  background-color: #f9f9f9;

  .van-hairline--top::after {
    border-top-width: 0px;
  }
}

::v-deep .van-tabs__nav {
  background-color: #f9f9f9;
}

::v-deep .search-box {
  display: flex;
  justify-content: space-between;
  width: 100%;
  z-index: 10;
  background-color: #fff;

  .van-dropdown-menu {
    width: 100%;

    .van-dropdown-menu__bar {
      box-shadow: 0 2px 12px rgba(255, 255, 255, 0.12);
    }
  }

  // .van-search {
  //   flex: 1;
  // }
}

//  ::v-deep .van-dropdown-item {
//   top: 228px !important;
// }

.device {
  background-color: #f9f9f9;
  padding: 40px 40px 20px 40px;
  box-sizing: border-box;
  color: $--mobile-text-sub;
  width: 100%;

  .device-item {
    background-color: #fff;
    border-radius: 60px;
    padding: 20px 100px 20px 100px;
    box-shadow: 0 4px 8px 0 rgba(0, 0, 0, 0.1), 0 6px 20px 0 rgba(0, 0, 0, 0.1);
  }

  .device-content {
    // padding: 50px 0px 50px 0px;
    // height: 400px;
    font-size: 50px;

    p {
      margin: 10px 0 10px 0;
    }
  }

  .device-item-img {
    width: 256px;
    height: 256px;

    img {
      width: 100%;
      height: 100%;
    }
  }

  .device-item-text {
    padding: 20px 0px 20px 0px;
    // margin-left: 10px;
    // width: calc(100% - 256px - 10px);
    border-bottom: 1px solid #dedddd;
  }

  .device-item-content {
    display: flex;
    justify-content: space-between;
    align-items: center;

    span {
      font-size: 72px;
    }
  }

  .device-name {
    font-size: 72px;
    color: $--mobile-text-main;
  }

  .device-name-icon {
    color: $-mobile-primary;
    margin-right: 2px;
  }

  .device-code {
    color: $--mobile-text-sub;
    font-size: 82px;
  }

  .device-item-title {
    color: #49a1f9;
    margin-right: 2px;
  }

  .device-status .van-tag {
    padding: 4px 6px;
  }

  .van-tag {
    width: 200px;
    display: flex;
    justify-content: center;
  }
}

.myStyle {
  padding: 40px 40px 40px 40px;
}
</style>
<style lang="scss">
@import '@/assets/css/vant-custom';
</style>
